@@ -1,6 +1,7 @@
 from functools import wraps
 from os.path import join
 from os import getcwd
+from datetime import datetime
 
 
 def singleton(cls):
@@ -15,6 +16,16 @@ def singleton(cls):
     return _singleton
 
 
+class Time:
+    def __init__(self, cls):
+        wraps(cls)(self)
+
+    def __call__(self, *args, **kwargs):
+        self.__func()
+        print("时间:", datetime.now())
+        return self.__wrapped__(*args, **kwargs)
+
+
 @singleton
 class Log:
     def __init__(self, file_name):
@@ -46,3 +57,7 @@ class Log:
         print("This is a error,look {}".format(
             join(getcwd(), self.file_name))
         )
+
+
+if __name__ == '__main__':
+    demo = Log()
